---@class IXPhysicalManager : XOwnerRecorder
IXPhysicalManager = {}


---@public 初始化
---@return boolean
function IXPhysicalManager:Init() end


---@public 释放
---@return void
function IXPhysicalManager:Release() end


---@public 创建一个物理场景
---@param szSceneName string 场景名称
---@return IXPhysicsScene 场景指针，创建失败返回NULL
function IXPhysicalManager:CreateScene(szSceneName) end


---@public 从一个模型实例的某个Mesh上获取布料实例
---@param pInstance IXModelInstance 模型实例的指针
---@param szMeshName string mesh的名称
---@return IXCloth 布料实例的指针,如果没有绑定布料返回空指针
function IXPhysicalManager:GetCloth(pInstance, szMeshName) end


---@public 从一个模型实例获取所有的布料实例
---@param pInstance IXModelInstance 模型实例的指针
---@return IXCloth[]
---@return void
function IXPhysicalManager:GetCloth(pInstance) end


---@public 获取所有带布料的mesh名称
---@param pInstance IXModelInstance 模型实例的指针
---@return string[]
---@return void
function IXPhysicalManager:GetMeshNameWithCloth(pInstance) end


---@public 从硬盘上加载一个布料实例
---@param szPath string 布料的路径
---@return IXCloth 布料实例的指针,如果失败返回空指针
function IXPhysicalManager:CreateCloth(szPath) end


---@public 自动将布料实例与模型绑定，根据材质名进行匹配
---@param pInstance IXModelInstance 模型实例指针
---@param nSkinIndex number
---@param pCloth IXCloth 布料实例指针
---@return boolean
function IXPhysicalManager:AddCloth(pInstance, nSkinIndex, pCloth) end


---@public 移除模型实例某个mesh的所有布料
---@param pInstance IXModelInstance 模型实例指针
---@return void
function IXPhysicalManager:RemoveCloth(pInstance) end


---@public 将布料实例与模型的某个mesh绑定
---@param pInstance IXModelInstance 模型实例指针
---@param nSkinIndex number
---@param szMeshName string 模型mesh名称
---@param pCloth IXCloth 布料实例指针
---@return boolean 失败情况：mesh已绑定/cloth已绑定/meshName未找到/骨骼名称不匹配等.
function IXPhysicalManager:AddCloth(pInstance, nSkinIndex, szMeshName, pCloth) end


---@public 移除模型实例某个mesh的布料
---@param pInstance IXModelInstance 模型实例指针
---@param szMeshName string 模型mesh名称
---@return void
function IXPhysicalManager:RemoveCloth(pInstance, szMeshName) end


---@public 将模型实例当前的布料信息设置到Skin上
---@param pInstance IXModelInstance 模型实例指针
---@return void
function IXPhysicalManager:SetClothInfoToSkin(pInstance) end


---@public 保存布料文件
---@param szFile string
---@param pCloth IXCloth
---@return boolean
function IXPhysicalManager:SaveCloth(szFile, pCloth) end


---@public 创建一个刚体
---@param eType number 刚体类型
---@param pBindObject XBaseCoordSpace 一个BaseCoordSpace类,当前有模型和特效
---@return IXRigidBody
function IXPhysicalManager:CreateRigidBody(eType, pBindObject) end


---@public 从硬盘上加载一个物理资源(碰撞体)
---@param sz string
---@param bReload boolean 是否重加载
---@return IXPhysicsRes 物理资源的指针,如果失败返回空指针
function IXPhysicalManager:LoadPhysicsRes(sz, bReload) end


---@public 从骨骼物理资源创建骨骼物理实例
---@param szSkeletalPhysicsRes string 骨骼物理资源的路径
---@param pModelInstance IXModelInstance
---@param pOwningScene IXPhysicsScene
---@return IXSkeletalPhysicsInstance 骨骼物理实例的指针,如果失败返回空指针
function IXPhysicalManager:CreateSkeletalPhysicsInstance(szSkeletalPhysicsRes, pModelInstance, pOwningScene) end


---@public 设置全局风速
---@param fWindSpeed number
---@return void
function IXPhysicalManager:SetWindSpeed(fWindSpeed) end


---@public 获取全局风速
---@return number
function IXPhysicalManager:GetWindSpeed() end


---@public 设置全局风向
---@param vDir XVECTOR3
---@return void
function IXPhysicalManager:SetWindDir(vDir) end


---@public 获取全局风向
---@return XVECTOR3
function IXPhysicalManager:GetWindDir() end


