---@class XUIImage : XUIWidget
XUIImage = {}


---@type number @enum ImageType
XUIImage.Simple = 0


---@type number @enum ImageType
XUIImage.Sliced = 0


---@type number @enum ImageType
XUIImage.Fill = 0


---@type number @enum ImageType
XUIImage.Polygon = 0


---@type number @enum ImageType
XUIImage.Quad = 0


---@type number @enum ImageFillMode
XUIImage.Horizontal = 0


---@type number @enum ImageFillMode
XUIImage.Vertical = 0


---@type number @enum ImageFillMode
XUIImage.Radial90 = 0


---@type number @enum ImageFillMode
XUIImage.Radial180 = 0


---@type number @enum ImageFillMode
XUIImage.Radial360 = 0


---@type number @enum Origin_HorizontalFill
XUIImage.Left = 0


---@type number @enum Origin_HorizontalFill
XUIImage.Right = 0


---@type number @enum Origin_VerticalFill
XUIImage.Top = 0


---@type number @enum Origin_VerticalFill
XUIImage.Bottom = 0


---@type number @enum Origin_90Fill
XUIImage.BottomLeft = 0


---@type number @enum Origin_90Fill
XUIImage.TopLeft = 0


---@type number @enum Origin_90Fill
XUIImage.TopRight = 0


---@type number @enum Origin_90Fill
XUIImage.BottomRight = 0


---@type number @enum Origin_180Fill
XUIImage.Bottom = 0


---@type number @enum Origin_180Fill
XUIImage.Left = 0


---@type number @enum Origin_180Fill
XUIImage.Top = 0


---@type number @enum Origin_180Fill
XUIImage.Right = 0


---@type number @enum Origin_360Fill
XUIImage.Bottom = 0


---@type number @enum Origin_360Fill
XUIImage.Right = 0


---@type number @enum Origin_360Fill
XUIImage.Top = 0


---@type number @enum Origin_360Fill
XUIImage.Left = 0


---@public 创建并返回一个空的控件实例的指针
---@return XUIImage
function XUIImage:Create() end


---@public 根据图片名字创建一个Image
---@param nTag number 该纹理路径的索引值，XUIImage可以持有多张纹理，即不同nTag可以对应不同纹理路径，默认从0开始
---@param strTextureName string 纹理的文件路径，该路径若是pvr/ktx则不需要传后缀名，引擎通过当前平台是android/ios自动补后缀，若是png/jpg则需要传后缀名。
---@param texType number 路径的类型,相对路径/绝对路径。
---@return XUIImage 创建的XUIImage实例
function XUIImage:Create(nTag, strTextureName, texType) end


---@public XUIImage_SetUseTexture00
---@param bUse boolean
---@return void
function XUIImage:SetUseTexture(bUse) end


---@public 获取是否使用纹理
---@return boolean 是否使用纹理
function XUIImage:IsUseTexture() end


---@public 加载纹理
---@param nTag number 该纹理路径的索引值，XUIImage可以持有多张纹理，即不同nTag可以对应不同纹理路径，默认从0开始。
---@param strTextureName string 纹理的文件路径，该路径若是pvr/ktx则不需要传后缀名，引擎通过当前平台是android/ios自动补后缀，若是png/jpg则需要传后缀名。
---@param texType number 路径的类型,相对路径/绝对路径。
---@return boolean 是否加载成功。
function XUIImage:LoadTexture(nTag, strTextureName, texType) end


---@public 显示索引为nTag的图片
---@param nTag number 该值为Create、或者LoadTexture时传入的nTag值，XUIImage控件会展示对应的图片。
---@return void
function XUIImage:ShowTexture(nTag) end


---@public 删除指定tag对应的纹理
---@param nTag number 对应的索引
---@return void
function XUIImage:RemoveTexture(nTag) end


---@public 获取纹理数目
---@return number 纹理数目
function XUIImage:GetTextureNum() end


---@public 获取当前正在显示的纹理索引
---@return number 正在显示的纹理索引
function XUIImage:GetCurrentTag() end


---@public 获取指定tag的纹理路径，并返回
---@param nTag number 指定tag
---@return string 纹理路径
function XUIImage:GetTexturePath(nTag) end


---@public 查询指定tag的纹理是否存在
---@param nTag number 指定tag
---@return boolean 纹理是否存在
function XUIImage:IsTextureExisted(nTag) end


---@public 获取是否使用纹理的尺寸
---@return boolean 是否使用纹理的尺寸
function XUIImage:IsFollowTextureSize() end


---@public 设置是否使用纹理的尺寸
---@param bFollow boolean 是否使用纹理的尺寸
---@return void
function XUIImage:SetFollowTextureSize(bFollow) end


---@public 按百分比显示图片的一部分
---@param vLTPercent XVECTOR2 图片左上角的百分比
---@param vBRPercent XVECTOR2 图片右下角的百分比
---@return void
function XUIImage:SetRectPercent(vLTPercent, vBRPercent) end


---@public XUIImage_SetFlipX00
---@param bFlip boolean
---@return void
function XUIImage:SetFlipX(bFlip) end


---@public XUIImage_IsFlipX00
---@return boolean
function XUIImage:IsFlipX() end


---@public 获取指定tag的纹理原始大小
---@param nTag number 指定tag
---@return XVECTOR2 纹理原始大小（返回类型XVECTOR2）
function XUIImage:GetTextureOriginalSize(nTag) end


---@public XUIImage_SetUseSequence00
---@param bUse boolean
---@return void
function XUIImage:SetUseSequence(bUse) end


---@public 获取XUIImage是否启用序列帧模式
---@return boolean 是否启用序列帧模式
function XUIImage:IsUseSequence() end


---@public 获取XUIImage是否正在播放序列帧
---@return boolean 是否正在播放序列帧
function XUIImage:IsSequencePlaying() end


---@public 设置播放序列帧
---@param bPlay boolean 是否播放序列帧
---@return void
function XUIImage:PlaySequence(bPlay) end


---@public 重置序列帧，重置序列帧为未播放时的初始状态。
---@return void
function XUIImage:ResetSequence() end


---@public 设置序列帧UV
---@param vTile XVECTOR2 参数为XVECTOR2类型，对应的x为序列帧图片横向的帧图片个数，y为纵向的帧图片个数。举例：有个序列帧图片，图片上为34共12帧图片，那么参数需要传入为XVECTOR2(3,4)。
---@return void
function XUIImage:SetUVTile(vTile) end


---@public 设置序列帧UV
---@param fUTile number
---@param fVTile number
---@return void
function XUIImage:SetUVTile(fUTile, fVTile) end


---@public 获取序列帧UV
---@return XVECTOR2 获取当前序列帧UV设置。
function XUIImage:GetUVTile() end


---@public 设置序列帧动画的FPS
---@param fFPS number 序列帧动画的FPS
---@return void
function XUIImage:SetSequenceFPS(fFPS) end


---@public 获取序列帧动画的FPS
---@return number 序列帧动画的FPS
function XUIImage:GetSequenceFPS() end


---@public 设置序列帧图片中保存的真正的帧数
---@param nNum number 序列帧图片中保存的真正的帧数。举例：有个序列帧图片，图片格式为34共12帧图片，但是最后一帧是空白的（并没有图片），那么参数应当传为11。
---@return void
function XUIImage:SetActualFrameNum(nNum) end


---@public 获取当前序列帧图片中保存的真正的帧数
---@return number 返回值为通过SetActualFrameNum传入的值，默认为1
function XUIImage:GetActualFrameNum() end


---@public XUIImage_SetActualFrameBegin00
---@param nNum number
---@return void
function XUIImage:SetActualFrameBegin(nNum) end


---@public XUIImage_GetActualFrameBegin00
---@return number
function XUIImage:GetActualFrameBegin() end


---@public 设置当前播放到第nFrame帧。
---@param nFrame number 当前播放到第nFrame帧。
---@return void
function XUIImage:SetCurrentFrame(nFrame) end


---@public 返回当前播放到第nFrame帧。
---@return number 当前播放到第nFrame帧。
function XUIImage:GetCurrentFrame() end


---@public 设置是否使用九宫格
---@param bSet boolean 是否使用九宫格
---@return void
function XUIImage:Enable9Slice(bSet) end


---@public 判断是否使用九宫格
---@return boolean 是否使用九宫格
function XUIImage:Is9SliceEnabled() end


---@public 设置九宫格左侧部分宽度(单位:像素)
---@param fLeft number 左侧部分宽度
---@return void
function XUIImage:SetSliceLeft(fLeft) end


---@public 获取九宫格左侧部分宽度(单位:像素)
---@return number 左侧部分宽度
function XUIImage:GetSliceLeft() end


---@public 设置九宫格右侧部分宽度(单位:像素)
---@param fRight number 右侧部分宽度
---@return void
function XUIImage:SetSliceRight(fRight) end


---@public 获取九宫格右侧部分宽度(单位:像素)
---@return number 右侧部分宽度
function XUIImage:GetSliceRight() end


---@public 设置九宫格上侧部分宽度(单位:像素)
---@param fTop number 上侧部分宽度
---@return void
function XUIImage:SetSliceTop(fTop) end


---@public 获取九宫格上侧部分宽度(单位:像素)
---@return number 上侧部分宽度
function XUIImage:GetSliceTop() end


---@public 设置九宫格下侧部分宽度(单位:像素)
---@param fBottom number
---@return void
function XUIImage:SetSliceBottom(fBottom) end


---@public 获取九宫格下侧部分宽度(单位:像素)
---@return number 下侧部分宽度
function XUIImage:GetSliceBottom() end


---@public 设置九宫格小图的UV
---通常情况不需要调用
---@param vLT XVECTOR2
---@param vBR XVECTOR2
---@return void
function XUIImage:SetTListUV(vLT, vBR) end


---@public 获取九宫格下侧部分宽度(单位:像素)
---@return XVECTOR2
---@return XVECTOR2
---@return void
function XUIImage:GetTlistUV() end


---@public 获取纹理指针
---@return  XUITexture 纹理指针
function XUIImage:GetUITexture() end


---@public 设置是否使用遮罩纹理
---@param bUse boolean 是否使用遮罩纹理
---@return void
function XUIImage:SetUseMaskTexture(bUse) end


---@public 获取是否使用遮罩纹理
---@return boolean 是否使用遮罩纹理
function XUIImage:IsUseMaskTexture() end


---@public 加载遮罩纹理
---@param strTextureNamek string 遮罩纹理路径
---@return boolean
function XUIImage:LoadMaskTexture(strTextureNamek) end


---@public 获取遮罩纹理路径
---@return string 遮罩纹理路径
function XUIImage:GetMaskTexturePath() end


---@public 获取遮罩纹理指针
---@return  XUITexture 遮罩纹理指针
function XUIImage:GetUIMaskTexture() end


---@public 返回合图中小图名称
---@return string 合图中小图名称
function XUIImage:GetCurrentPlistSpriteName() end


---@public 设置图片类型
---@param type number 普通、九宫格、填充模式为兼容之前九宫格亦可通过enable9slice开启
---@return void
function XUIImage:SetImageType(type) end


---@public XUIImage_GetImageType00
---@return number
function XUIImage:GetImageType() end


---@public 设置填充模式
---@param type number 水平、垂直、径向90、径向180、径向360
---@return void
function XUIImage:SetFillMode(type) end


---@public XUIImage_GetImageFillMode00
---@return number
function XUIImage:GetImageFillMode() end


---@public 设置填充数值
---@param amount number [0,1]
---@return void
function XUIImage:SetFillAmount(amount) end


---@public XUIImage_GetFillAmount00
---@return number
function XUIImage:GetFillAmount() end


---@public 设置填充起点
---@param origin number
---@return void
function XUIImage:SetHorizontalFillOrigin(origin) end


---@public XUIImage_SetVerticalFillOrigin00
---@param origin number
---@return void
function XUIImage:SetVerticalFillOrigin(origin) end


---@public XUIImage_Set90FillOrigin00
---@param origin number
---@return void
function XUIImage:Set90FillOrigin(origin) end


---@public XUIImage_Set180FillOrigin00
---@param origin number
---@return void
function XUIImage:Set180FillOrigin(origin) end


---@public XUIImage_Set360FillOrigin00
---@param origin number
---@return void
function XUIImage:Set360FillOrigin(origin) end


---@public XUIImage_SetFillOrigin00
---@param origin number
---@return void
function XUIImage:SetFillOrigin(origin) end


---@public XUIImage_GetFillOrigin00
---@return number
function XUIImage:GetFillOrigin() end


---@public 设置填充是否翻转
---@param reverse boolean
---@return void
function XUIImage:SetFillReverse(reverse) end


---@public XUIImage_GetFillReverse00
---@return boolean
function XUIImage:GetFillReverse() end


---@public XUIImage_GetSubviewParam00
---@return SubviewParam
function XUIImage:GetSubviewParam() end


---@public XUIImage_UseSubViewFromMainEditor00
---@return boolean
function XUIImage:UseSubViewFromMainEditor() end


---@public XUIImage_SetUseSubViewFromMainEditor00
---@param use boolean
---@return void
function XUIImage:SetUseSubViewFromMainEditor(use) end


---@public 加载plist 快捷方式
---@param spritename string 小图名称可不带后缀会自行匹配pvrtgapngktx
---@param tag number
---@return void
function XUIImage:LoadPlistTexture(spritename, tag) end


