---Label(文本)是Node的子类,它知道如何渲染文本。
---文本可以通过以下方法来创建:
---1 一个TTF字体文件。
---2 一个位图字体文件。
---3 一个字符映射文件。
---4 内置的系统字体。
---@class XUILabel : XUIWidget
XUILabel = {}


---@type number @enum ELabelType
XUILabel.XUIL_TTF = 0


---@type number @enum ELabelType
XUILabel.XUIL_SYSTEMF = 0


---@type number @enum ELabelType
XUILabel.XUIL_IMAGE = 0


---@public 使用默认设置分配和初始化一个文本
---@return XUILabel 控件指针
function XUILabel:CreateWithTTF() end


---@public 使用FreeType2库创建和初始化一个文本
---@param ttfConfig  XUITTFConfig ttf信息
---@param strUtf8Text string 最初文本内容
---@param nLineWidth number 线宽
---@param hAlignment number 水平对齐方式
---@param vAlignment number 水平对齐方式
---@return XUILabel 返回创建的Label指针
function XUILabel:CreateWithTTF(ttfConfig, strUtf8Text, nLineWidth, hAlignment, vAlignment) end


---@public 使用FreeType2库创建和初始化一个文本
---@param strUtf8Text string 最初文本内容
---@param strFontFilePath string 一个TTF字体文件
---@param fontPointSize number 字体大小，这个值必须大于0
---@param nLineWidth number 线宽
---@param hAlignment number 水平对齐方式
---@param vAlignment number 水平对齐方式
---@return XUILabel 返回创建的Label指针
function XUILabel:CreateWithTTF(strUtf8Text, strFontFilePath, fontPointSize, nLineWidth, hAlignment, vAlignment) end


---@public 基于平台相关的API创建一个默认的文本
---@return XUILabel 返回创建的Label指针
function XUILabel:CreateWithSystemFont() end


---@public 基于平台相关的API创建和初始化一个文本
---@param strUtf8Text string 最初文本内容
---@param fontName string 一个字体文件或字体名称
---@param fontPointSize number 字体大小，这个值必须大于0
---@param hAlignment number 水平对齐方式
---@param vAlignment number 水平对齐方式
---@return XUILabel 返回创建的Label指针
function XUILabel:CreateWithSystemFont(strUtf8Text, fontName, fontPointSize, hAlignment, vAlignment) end


---@public XUILabel_CreateWhithImageFont00
---@param ttfConfig  XUIIMFConfig
---@return XUILabel
function XUILabel:CreateWhithImageFont(ttfConfig) end


---@public XUILabel_new00
---@param hAlignment number
---@param vAlignment number
---@return XUILabel
function XUILabel:new(hAlignment, vAlignment) end


---@public 应用设置
---@return void
function XUILabel:UpdateImmediately() end


---@public 设置字体大小
---@param fPointSize number
---@return void
function XUILabel:SetTextPointSize(fPointSize) end


---@public XUILabel_GetTextPointSize00
---@return number
function XUILabel:GetTextPointSize() end


---@public 设置是否自动换行
---@param bEnableWrap boolean 默认true，为false时，要求m_fLabelWidth>0.0f，才会进行自动换行处理。
---@return void
function XUILabel:SetEnableWrap(bEnableWrap) end


---@public XUILabel_GetEnableWrap00
---@return boolean
function XUILabel:GetEnableWrap() end


---@manual 设置文本内容 手动导出 增加扩展，支持传入任何类型
---@public XUILabel_SetString_manual
---@param strUtf8Text string
---@return void
function XUILabel:SetString(strUtf8Text) end


---@public 获取文本内容
---@return string
function XUILabel:GetString() end


---@public 获取文本大小
---@return number
function XUILabel:GetStringCount() end


---@public 设置文本对齐方式
---@param hAlign number 水平对齐
---@param vAlign number 竖直对齐
---@return void
function XUILabel:SetAlignment(hAlign, vAlign) end


---@public 设置文本水平对齐方式
---@param hAlign number 水平对齐
---@return void
function XUILabel:SetHAlignMent(hAlign) end


---@public 设置文本垂直对齐方式
---@param vAlign number 垂直对齐
---@return void
function XUILabel:SetVAlignMent(vAlign) end


---@public XUILabel_GetHAlignment00
---@return number
function XUILabel:GetHAlignment() end


---@public XUILabel_GetVAlignment00
---@return number
function XUILabel:GetVAlignment() end


---@public 设置文本区域
---即Label的宽度和高度，按文字行最大宽度和高度自动调整
---@param fWidth number
---@param fHeight number 高度当fHeight>0.0，且文字总高度超出fHeight，则截断文字。fWidth或fHeight为小于等于0.0，则表示大小自动适应。
---@return void
function XUILabel:SetDimensions(fWidth, fHeight) end


---@public 获取文本区域
---@return XVECTOR2
function XUILabel:GetDimensions() end


---@public 设置文本颜色
---@param clr  XCOLORBASE 文本颜色
---@return void
function XUILabel:SetTextColor(clr) end


---@public XUILabel_GetTextColor00
---@return  XCOLORBASE
function XUILabel:GetTextColor() end


---@public 设置文本渐变颜色-上层颜色
---@param clr  XCOLORBASE 文本上层颜色
---@return void
function XUILabel:SetTextUpperColor(clr) end


---@public XUILabel_GetTextUpperColor00
---@return  XCOLORBASE
function XUILabel:GetTextUpperColor() end


---@public 设置文本渐变颜色-下层颜色
---@param clr  XCOLORBASE 文本下层颜色
---@return void
function XUILabel:SetTextLowerColor(clr) end


---@public XUILabel_GetTextLowerColor00
---@return  XCOLORBASE
function XUILabel:GetTextLowerColor() end


---@public 设置文本描边颜色
---@param clrOutLine  XCOLORBASE 描边颜色
---@return void
function XUILabel:SetOutlineColor(clrOutLine) end


---@public XUILabel_GetOutlineColor00
---@return  XCOLORBASE
function XUILabel:GetOutlineColor() end


---@public 设置文本描边宽度
---@param nOutlineSize number
---@return void
function XUILabel:SetOutlineSize(nOutlineSize) end


---@public XUILabel_GetOutlineSize00
---@return number
function XUILabel:GetOutlineSize() end


---@public 获取文本描边宽度
---设置文本的字间距, 仅TTF文字支持
---@param fAdditionalKerning number 字间距值
---@return void 返回描边颜色
function XUILabel:SetAdditionalKerning(fAdditionalKerning) end


---@public XUILabel_GetAdditionalKerning00
---@return number
function XUILabel:GetAdditionalKerning() end


---@public 设置文本的行间距, 仅TTF文字支持
---@param fLineSpacing number
---@return void
function XUILabel:SetLineSpacing(fLineSpacing) end


---@public XUILabel_GetLineSpacing00
---@return number
function XUILabel:GetLineSpacing() end


---@public 更改字体
---@param strPath string
---@return void
function XUILabel:SetTTFFontPath(strPath) end


---@public XUILabel_GetTTFFontPath00
---@return string
function XUILabel:GetTTFFontPath() end


---@public XUILabel_SetFontPath00
---@param strPath string
---@return void
function XUILabel:SetFontPath(strPath) end


---@public XUILabel_GetFontPath00
---@return string
function XUILabel:GetFontPath() end


---@public XUILabel_SetPListPath00
---@param strPath string
---@return void
function XUILabel:SetPListPath(strPath) end


---@public XUILabel_GetImgFontPath00
---@return string
function XUILabel:GetImgFontPath() end


---@public 设置是否允许在西文单词中换行, 仅TTF文字支持
---@param bBreakOfWesternWord boolean 是否在西文中换行
---@return void
function XUILabel:SetBreakOfWesternWord(bBreakOfWesternWord) end


---@public XUILabel_GetBreakOfWesternWord00
---@return boolean
function XUILabel:GetBreakOfWesternWord() end


---@public 切换到系统字体
---@return void
function XUILabel:ChangeToSystemFont() end


---@public 设置系统字体名称
---@param strFontName string 系统字体名称
---@return void
function XUILabel:SetSystemFontName(strFontName) end


---@public XUILabel_GetSystemFontName00
---@return string
function XUILabel:GetSystemFontName() end


---@public XUILabel_GetLabelType00
---@return number
function XUILabel:GetLabelType() end


---@public XUILabel_SetLabelType00
---@param type number
---@return void
function XUILabel:SetLabelType(type) end


---@public XUILabel_SetRichText00
---@param tichtext string
---@return void
function XUILabel:SetRichText(tichtext) end


---@public XUILabel_SetTextFormat00
---@param _format  XUITextFormat
---@return void
function XUILabel:SetTextFormat(_format) end


---@public XUILabel_GetFontTextures00
---@return IXTexture2D[]
function XUILabel:GetFontTextures() end


