---@class XUIWidget : XUINode
XUIWidget = {}


---@type number @enum FocusDirection
XUIWidget.XUI_LEFT = 0


---@type number @enum FocusDirection
XUIWidget.XUI_RIGHT = 0


---@type number @enum FocusDirection
XUIWidget.XUI_UP = 0


---@type number @enum FocusDirection
XUIWidget.XUI_DOWN = 0


---@type number @enum PositionType
XUIWidget.XUI_ABSOLUTE = 0


---@type number @enum PositionType
XUIWidget.XUI_PERCENT = 0


---@type number @enum SizeType
XUIWidget.XUI_ABSOLUTE = 0


---@type number @enum SizeType
XUIWidget.XUI_PERCENT = 0


---@type number @enum TouchEventType
XUIWidget.XUI_BEGAN = 0


---@type number @enum TouchEventType
XUIWidget.XUI_MOVED = 0


---@type number @enum TouchEventType
XUIWidget.XUI_ENDED = 0


---@type number @enum TouchEventType
XUIWidget.XUI_CANCELED = 0


---@type number @enum BrightStyle
XUIWidget.XUI_NONE = 0


---@type number @enum BrightStyle
XUIWidget.XUI_NORMAL = 0


---@type number @enum BrightStyle
XUIWidget.XUI_HIGHLIGHT = 0


---@type number @enum TextureResType
XUIWidget.XUI_LOCAL = 0


---@type number @enum TextureResType
XUIWidget.XUI_PLIST = 0


---@type number @enum TextureResType
XUIWidget.XUI_RTT_Tex = 0


---@public 创建并返回一个空的控件实例的指针
---@return XUIWidget 控件指针
function XUIWidget:Create() end


---@public 设置是否启用了控件
---如果设置为true则启用了控件，部件可以响应触摸事件，如果设置为false则控件是禁用的，不会响应触摸事件。
---默认值是true,一个控件是默认启用触摸
---@param enabled boolean 设置为true来启用触摸，否则不启用触摸响应
---@return void
function XUIWidget:SetEnabled(enabled) end


---@public 判断是否启用了控件
---@return boolean 是否启用状态
function XUIWidget:IsEnabled() end


---@public 设置控件颜色
---@param color  XCOLORBASE 要设置的颜色
---@return void
function XUIWidget:SetColor(color) end


---@public 设置控件是否高亮，默认值是true，若设置为false，则控件外观是暗的
---@param bBright boolean 是否高亮
---@return void
function XUIWidget:SetBright(bBright) end


---@public 获取控件是否高亮
---@return boolean 是否高亮
function XUIWidget:IsBright() end


---@public 设置控件的高亮风格
---@param style number 指定的高亮风格类型
---@return void
function XUIWidget:SetBrightStyle(style) end


---@public 设置是否响应触摸事件。默认值是false，控件默认是禁用触摸的。
---@param enabled boolean 是否响应触摸事件
---@return void
function XUIWidget:SetTouchEnabled(enabled) end


---@public 获取控件是否响应触摸事件
---@return boolean 是否响应触摸事件
function XUIWidget:IsTouchEnabled() end


---@public 设置是否高亮显示,默认值是false，控件默认不高亮显示
---@param bHighlight boolean 是否高亮显示
---@return void
function XUIWidget:SetHighlighted(bHighlight) end


---@public 获取是否高亮显示
---@return boolean 是否高亮显示
function XUIWidget:IsHighlighted() end


---@public 检查一个点是否在控件的内容空间里。 这个函数是用于检测控件的触摸响应区域
---@param vPoint XVECTOR2 点的位置
---@param pHitPos XVECTOR2 击中位置
---@return boolean
function XUIWidget:HitTest(vPoint, pHitPos) end


---@public 触摸事件开始时的回调函数
---@param pTouch XUITouch 触点信息
---@param pUnusedEvent XUIEvent 触摸事件信息
---@return boolean 如果需要响应这个触摸事件则返回true，否则返回false
function XUIWidget:OnTouchBegan(pTouch, pUnusedEvent) end


---@public 触摸事件中触点移动时的回调函数
---@param pTouch XUITouch 触点信息
---@param pUnusedEvent XUIEvent 触摸事件信息
---@return void
function XUIWidget:OnTouchMoved(pTouch, pUnusedEvent) end


---@public 触摸事件结束时的回调函数
---@param pTouch XUITouch 触点信息
---@param pUnusedEvent XUIEvent 触摸事件信息
---@return void
function XUIWidget:OnTouchEnded(pTouch, pUnusedEvent) end


---@public 触摸事件取消时的回调函数
---@param pTouch XUITouch 触点信息
---@param pUnusedEvent XUIEvent 触摸事件信息
---@return void
function XUIWidget:OnTouchCancelled(pTouch, pUnusedEvent) end


---@public 获取Widget的布局管理器（XUIWidgetAlignment）
---@return XUIWidgetAlignment
function XUIWidget:GetAlignment() end


---@public @param nPriority number
---@return void
function XUIWidget:SetListenerFixedPriority(nPriority) end


---@public 设置控件是否吞噬触摸事件
---@param bSwallow boolean true则吞噬触摸事件，false不吞噬
---@return void
function XUIWidget:SetSwallowTouches(bSwallow) end


---@public 获取控件是否吞噬触摸事件
---@return boolean 是否吞噬触摸事件
function XUIWidget:IsSwallowTouches() end


---@public 设置控件是否阻断消息继续传播
---@param bPass boolean true则不阻断传播,false则阻断传播。默认为false
---@return void
function XUIWidget:SetPassEvents(bPass) end


---@public 获取控件是否阻断消息继续传播
---@return boolean 是否是否阻断消息继续传播
function XUIWidget:IsPassEvents() end


---@public 查询控件是否拥有焦点
---@return boolean 是否拥有焦点
function XUIWidget:IsFocused() end


---@public 切换控件是否拥有焦点
---@param bFocus boolean 是否拥有焦点
---@return void
function XUIWidget:SetFocused(bFocus) end


---@public 查询控件是否拥有焦点
---@return boolean 返回true代表控件拥有焦点，反之返回false
function XUIWidget:IsFocusEnabled() end


---@public 允许控件接受焦点
---@param bEnable boolean 通过传递true/false来启用或禁用一个控件获取焦点
---@return void
function XUIWidget:SetFocusEnabled(bEnable) end


---@public 允许控件的触摸事件向上传播到父节点，设置为false会阻止向上传播
---@param bPropagate boolean true允许向上传播，false不允许
---@return void
function XUIWidget:SetPropagateTouchEvents(bPropagate) end


---@public 返回控件是否允许触摸事件传播到其父节点
---@return boolean 是否允许触摸事件传播到其父节点
function XUIWidget:IsPropagateTouchEvents() end


---@public 获取触点在控件被选中时的起始位置
---@return XVECTOR2 触点的起始位置
function XUIWidget:GetTouchBeganPosition() end


---@public 获取触点在控件被移动时的位置
---@return XVECTOR2 触点的位置
function XUIWidget:GetTouchMovePosition() end


---@public 获取触点在控件被选中时的结束位置
---@return XVECTOR2 触点的结束位置
function XUIWidget:GetTouchEndPosition() end


---@public 给控件设置一个布局参数
---@param parameter XUILayoutParameter 布局参数对象指针
---@return void
function XUIWidget:SetLayoutParameter(parameter) end


---@public 获取控件布局参数
---@return XUILayoutParameter 布局参数对象指针
function XUIWidget:GetLayoutParameter() end


---@public 通过传入的点的位置，计算返回选中的控件
---@param vHitPos XVECTOR2 拾取的点位置
---@return XUIWidget
function XUIWidget:GetSelectedWidget(vHitPos) end


---@manual xelua_XEngine_XUIWidget_AddTouchEventListener_manual
---@public XUIWidget_AddTouchEventListener_manual
---@param callback  std::function<void(XUINode*, XUIWidget::TouchEventType)>
---@return void
function XUIWidget:AddTouchEventListener(callback) end


---@public XUIWidget_TriggerTouchEventManually00
---@param eType number
---@return void
function XUIWidget:TriggerTouchEventManually(eType) end


---@manual xelua_XEngine_XUIWidget_AddClickEventListener_manual
---@public XUIWidget_AddClickEventListener_manual
---@param callback  std::function<void(XUINode*)>
---@return void
function XUIWidget:AddClickEventListener(callback) end


---@public XUIWidget_TriggerClickEventManually00
---@return void
function XUIWidget:TriggerClickEventManually() end


---@manual xelua_XEngine_XUIWidget_AddWidgetEventListener_manual
---@public XUIWidget_AddWidgetEventListener_manual
---@param callback  std::function<void(XUINode*, xint32)>
---@return void
function XUIWidget:AddWidgetEventListener(callback) end


---@public XUIWidget_TriggerWidgetEventManually00
---@param eEvent number
---@return void
function XUIWidget:TriggerWidgetEventManually(eEvent) end


---@public 开始启用长按事件的时间间隔
---@param delta number
---@return void
function XUIWidget:SetLongTouchInterval(delta) end


---@manual 设置长按回调事件
---@public XUIWidget_SetLongTouchedCallback_manual
---@param longTouchedCallback  std::function<void(void)>
---@return void
function XUIWidget:SetLongTouchedCallback(longTouchedCallback) end


---@public 判断当前是否处于长按状态
---@return boolean
function XUIWidget:IsInLongTouchStatus() end


---@public XUIWidget_SetTouchAreaOffset00
---@param vTouchCenter XVECTOR2
---@return void
function XUIWidget:SetTouchAreaOffset(vTouchCenter) end


---@public XUIWidget_GetTouchAreaOffset00
---@return XVECTOR2
function XUIWidget:GetTouchAreaOffset() end


---@public XUIWidget_SetTouchAreaSize00
---@param vTouchSize XVECTOR2
---@return void
function XUIWidget:SetTouchAreaSize(vTouchSize) end


---@public XUIWidget_GetTouchAreaSize00
---@return XVECTOR2
function XUIWidget:GetTouchAreaSize() end


