---@class XETreeNode : XOwnerRecorder
XETreeNode = {}


---@type number @enum AddNodeMode 尾部添加
XETreeNode.ANM_APPEND_TO_TAIL = 0


---@type number @enum AddNodeMode 头部添加
XETreeNode.ANM_INSERT_TO_HEAD = 0


---@type number @enum AddNodeMode 指定位置添加
XETreeNode.ANM_INSERT_TO_SPECIFIC = 0


---@public XETreeNode_new00
---@return XETreeNode
function XETreeNode:new() end


---@class XETreeNode__Manager : XOwnerRecorder
local XETreeNode__Manager = {}
XETreeNode.Manager = XETreeNode__Manager


---@public XETreeNode_Manager_new00
---@return XETreeNode__Manager
function XETreeNode__Manager:new() end


---@public 添加一个节点
---@param pNode XETreeNode 节点指针
---@return boolean 是否添加成功
function XETreeNode__Manager:AddTreeNode(pNode) end


---@public 删除一个节点
---@param pNode XETreeNode 节点指针
---@param bIncludeChild boolean 是否删除该节点子节点
---@param bReleaseMemory boolean 是否删除内存
---@param bReleaseNodes boolean 是否释放节点资源
---@return boolean 是否删除成功
function XETreeNode__Manager:RemoveTreeNode(pNode, bIncludeChild, bReleaseMemory, bReleaseNodes) end


---@public 删除子树节点
---@param pRootNode XETreeNode 子树节点指针
---@param bReleaseMemory boolean 是否删除内存
---@param bReleaseNodes boolean 是否释放节点资源
---@return boolean 是否删除成功
function XETreeNode__Manager:RemoveSubTreeNode(pRootNode, bReleaseMemory, bReleaseNodes) end


---@public 删除节点所在的整个树
---@param pNodeContext XETreeNode 节点指针
---@param bReleaseNodes boolean 是否释放节点资源
---@return boolean 是否删除成功
function XETreeNode__Manager:RemoveTree(pNodeContext, bReleaseNodes) end


---@public 删除节点所在的整个树，不包括该节点
---@param pNodeExcept XETreeNode 节点指针
---@param bReleaseNodes boolean 是否释放节点资源
---@return boolean 是否删除成功
function XETreeNode__Manager:RemoveTreeExceptNode(pNodeExcept, bReleaseNodes) end


---@public 释放所有树节点
---@param bReleaseNodes boolean 是否释放节点资源
---@return void
function XETreeNode__Manager:RemoveAllTreeNodes(bReleaseNodes) end


---@public 设置所属关卡
---@param pLevel XELevel
---@return void
function XETreeNode__Manager:SetOwnerLevel(pLevel) end


---@public 获取所属关卡
---@return XELevel 关卡指针，如果为NULL,表示节点树属于每个世界
function XETreeNode__Manager:GetOwnerLevel() end


---@public 获取所属世界（关卡可能已被销毁 ）
---@return XEWorld 世界指针，如果为NULL,表示节点树属于每个世界
function XETreeNode__Manager:GetOwnerWorld() end


---@public 获取节点列表
---@return XETreeNode[]
function XETreeNode__Manager:GetNodeList() end


---@public 获取指定节点类型的节点列表
---@param strNodeType string 节点类型
---@param pNodeContext  XETreeNode 想要获取的节点所在树上的某个已知节点
---@return XETreeNode[]
---@return number 找到的节点个数
function XETreeNode__Manager:GetNodesOfType(strNodeType, pNodeContext) end


---@public 查找指定节点
---@param strNodeName string 节点名称
---@param strNodeType string 节点类型,如果不需要指定，则设置为空
---@param pNodeContext  XETreeNode 想要获取的节点所在树上的某个已知节点
---@return XETreeNode 找到的节点指针
function XETreeNode__Manager:FindTreeNode(strNodeName, strNodeType, pNodeContext) end


---@public 判断是否含有指定节点
---@param pNode  XETreeNode 节点指针
---@return boolean 是否含有
function XETreeNode__Manager:HasTreeNode(pNode) end


---@public 判断指定节点是否延迟删除
---@param pNode XETreeNode 节点指针
---@return boolean 是否延迟删除
function XETreeNode__Manager:NodeDelayDelete(pNode) end


---@public 添加父节点
---@param manager XETreeNode::Manager 树节点管理器
---@param parent XETreeNode 父节点指针
---@param eAppend number 添加模式，默认为ANM_APPEND_TO_TAIL
---@param specificIndex number 指定位置，默认为空，当模式选择ANM_INSERT_TO_SPECIFIC，才需要传入此变量
---@return boolean 是否添加成功
function XETreeNode:AddParent(manager, parent, eAppend, specificIndex) end


---@public 添加子节点
---@param manager XETreeNode::Manager 树节点管理器
---@param child XETreeNode 子节点指针
---@param eAppend number 添加模式，默认为ANM_APPEND_TO_TAIL
---@param specificIndex number 指定位置，默认为空，当模式选择ANM_INSERT_TO_SPECIFIC，才需要传入此变量
---@return boolean 是否添加成功
function XETreeNode:AddChild(manager, child, eAppend, specificIndex) end


---@public 删除所有子节点
---@return void
function XETreeNode:RemoveAllChildren() end


---@public 从父节点移除
---@return void
function XETreeNode:RemoveFromParent() end


---@public 移除某个子节点
---@param child XETreeNode 指定子节点
---@return boolean
function XETreeNode:RemoveChild(child) end


---@public 移除某个父节点
---@param parent XETreeNode 指定父节点
---@return boolean
function XETreeNode:RemoveParent(parent) end


---@public 判断是否含有父节点
---@return boolean 是否含有父节点
function XETreeNode:HasParent() end


---@public 判断是否含有指定子节点
---@param node XETreeNode 指定子节点
---@return boolean 是否含有子节点
function XETreeNode:HasChild(node) end


---@public 判断是否含有子节点
---@return boolean 是否含有子节点
function XETreeNode:HasChild() end


---@public 判断本树上是否含有指定子节点
---@param node  XETreeNode 指定子节点
---@return boolean 本树上是否含有子节点
function XETreeNode:HasTreeNodeInOwnTree(node) end


---@public 获取父节点个数
---@return number 父节点个数
function XETreeNode:GetParentCount() end


---@public 获取子节点个数
---@return number 子节点个数
function XETreeNode:GetChildCount() end


---@public 获取子节点索引
---@param child  XETreeNode 指定子节点指针
---@return number 子节点索引
function XETreeNode:GetChildIndex(child) end


---@public 获取某个父节点索引
---@param pParent XETreeNode 指定父节点指针
---@return number 父节点索引
function XETreeNode:GetIndex(pParent) end


---@public 获取父节点迭代器
---@return IteratorWrapper<XETreeNode*> 父节点迭代器
function XETreeNode:GetParentIterator() end


---@public 获取子节点迭代器
---@return IteratorWrapper<XETreeNode*> 子节点迭代器
function XETreeNode:GetChildIterator() end


---@public 获取直接父节点列表
---@return XETreeNode[] 父节点列表
function XETreeNode:GetParentNodeList() end


---@public 获取直接子节点列表
---@return XETreeNode[] 子节点列表
function XETreeNode:GetChildNodeList() end


---@public 交换两个子节点
---@param pNode1 XETreeNode 子节点1
---@param pNode2 XETreeNode 子节点2
---@return boolean 是否交换成功
function XETreeNode:SwapChildren(pNode1, pNode2) end


---@public 获取根节点
---@return XETreeNode
function XETreeNode:GetRoot() end


---@public 获取第一个父节点
---@return XETreeNode
function XETreeNode:GetFirstParent() end


---@public 查找指定类型的节点
---@param nodetype string 指定节点类型
---@param fuzzy boolean 是否模糊查询
---@param recursion boolean 是否递归遍历
---@return XETreeNode[]
---@return number 查找到的节点个数
function XETreeNode:TravelNode(nodetype, fuzzy, recursion) end


---@public 获取节点管理器
---@return XETreeNode__Manager
function XETreeNode:GetNodeManager() end


---@public XETreeNode_GetNodeName00
---@return string
function XETreeNode:GetNodeName() end


---@public XETreeNode_GetTypeName00
---@return string
function XETreeNode:GetTypeName() end


---@public XETreeNode_UpdateNodeNameHash00
---@return number
function XETreeNode:UpdateNodeNameHash() end


---@public XETreeNode_UpdateTypeNameHash00
---@return number
function XETreeNode:UpdateTypeNameHash() end


---@public XETreeNode_GetNodeNameHash00
---@return number
function XETreeNode:GetNodeNameHash() end


---@public XETreeNode_GetTypeNameHash00
---@return number
function XETreeNode:GetTypeNameHash() end


---@public XETreeNode_HashString00
---@param str string
---@return number
function XETreeNode:HashString(str) end


