---@type number @enum ETeleportType
TeleportTypeNone = 0


---@type number @enum ETeleportType
TeleportPhysics = 0


---@type number @enum ETeleportType
ResetPhysics = 0


---@type number @enum EMoveComponentFlags
MOVECOMP_NoFlags = 0


---@type number @enum EMoveComponentFlags
MOVECOMP_IgnoreBases = 0


---@type number @enum EMoveComponentFlags
MOVECOMP_SkipPhysicsMove = 0


---@type number @enum EMoveComponentFlags
MOVECOMP_NeverIgnoreBlockingOverlaps = 0


---@class XEActorComponent : XEEventReceiver
XEActorComponent = {}


---@public 获取当前XEActorComponent的类型，默认是ActorComponent。如XEModelComponent的类型是ModelComponent；
---XEParticleSystemComponent的类型是ParticleSystemComponent。
---@return string
function XEActorComponent:GetTypeName() end


---@public 释放当前组件申请的资源
---@return void
function XEActorComponent:Release() end


---@public 清空当前组件及其children的所有实例
---@return void
function XEActorComponent:Empty() end


---@public 更新物理
---@param fDelMs number
---@return void
function XEActorComponent:PresentPhysics(fDelMs) end


---@public XEActorComponent_LoadAsset00
---@param pPath string
---@return boolean
function XEActorComponent:LoadAsset(pPath) end


---@public 将当前组件附加到父节点组件pParent上面，也就是将当前组件作为pParent的子组件
---@param pParent XEActorComponent 将被当前组件附加的父节点组件
---@return void
function XEActorComponent:AttachToComponent(pParent) end


---@public 将当前组件从其父节点组件上移除，也就是将当前组件与其父节点组件解除父子关系
---@return void
function XEActorComponent:DetachFromParent() end


---@public 根据pActor初始化当前组件的部分数据，包含当前组件所属的XEActor及当前组件的索引等
---@param pActor XEActor 当前组件所属的XEActor，一般而言，每个XEActor都至少包含一个组件
---@return void
function XEActorComponent:Initialize(pActor) end


---@public 获取当前组件的AABB包围盒。对于不同类型的组件，其AABB包围盒数据不同。
---如XEActorComponent的包围盒数据是基于组件的世界坐标和半径计算出来的；
---而XEModelComponent的包围盒是从引擎中获取模型实例已计算好的数据
---@param pfRadius number 当前组件用于计算AABB包围盒大小的参数因子
---@return XCusAABB
function XEActorComponent:GetCusAABB(pfRadius) end


---@public 射线拾取
---@param hr XEHitResult [in][out]拾取结果结构体，包含输入的射线起始位置和方向；输出的拾取到的XEActor、拾取到的3D场景的坐标点等，具体参考XEHitResult的介绍.
---@return XEHitResult[]
---@return boolean 表示是否拾取到
function XEActorComponent:RayPick(hr) end


---@public 射线拾取
---@param hr XEHitResult [in][out]拾取结果结构体，包含输入的射线起始位置和方向；输出的拾取到的XEActor、拾取到的3D场景的坐标点等，具体参考XEHitResult的介绍.
---@param viewport XViewport 当前组件所在世界绑定的视口指针
---@param vScreenPoint XVECTOR2 拾取时的像素坐标，例如在编辑器的窗口中进行拾取时，鼠标的坐标。
---@return XEHitResult[]
---@return boolean 表示是否拾取到
function XEActorComponent:RayPick(hr, viewport, vScreenPoint) end


---@public 射线拾取（只拾取当前组件，不包括child）
---@param hr XEHitResult [in][out]拾取结果结构体，包含输入的射线起始位置和方向；输出的拾取到的XEActor、拾取到的3D场景的坐标点等，具体参考XEHitResult的介绍.
---@return boolean 表示是否拾取到
function XEActorComponent:RayPick(hr) end


---@public 序列化前更新组件数据
---@return void
function XEActorComponent:UpdateForSerialize() end


---@public 设置当前组件和当前组件所关联的子XEActor的删除状态
---@param bDelete boolean
---@return void
function XEActorComponent:SetDeleted(bDelete) end


---@public 当当前组件被绑定到其他槽上时，用于根据槽的变换更新当前组件的状态[Tick]。
---@param pBindSocketIns XEBindSocketInstance
---@param matWorld XMATRIX4
---@return void
function XEActorComponent:OnSocketTick(pBindSocketIns, matWorld) end


---@public 当当前组件被绑定到其他槽上时，渲染该插槽上的物体。
---@param pBindSocketIns XEBindSocketInstance
---@return void
function XEActorComponent:OnSocketRender(pBindSocketIns) end


---@public XEActorComponent_SetHidden00
---@param bHide boolean
---@return void
function XEActorComponent:SetHidden(bHide) end


---@public 该组件添加到子视图中，子视图位于该组件的所属世界中，要先设置该组件的世界所属。子组件将会同步进subview
---@param pSubviewName string 渲染的子视图名称
---@param bRenderOnlyInSubview boolean 是否只在子视图中渲染
---@param bResetupSubview boolean 是否立即重新安装子视图
---@return boolean 是否成功
function XEActorComponent:AddToSubview(pSubviewName, bRenderOnlyInSubview, bResetupSubview) end


---@public 从指定子视图中删除， 子组件将会同步从subview中移除
---@param bResetupSubview boolean 是否立即重新安装子视图
---@param pSubviewName string 指定从子视图中移除的名称，如果为空，则该渲染图元将会从所有关联子视图中移除。
---@return boolean 是否成功
function XEActorComponent:RemoveFromSubview(bResetupSubview, pSubviewName) end


---@public 是否已经存在于一个子视图中，如果子组件有一个在subview中，则该组件判定为在subview中
---@param pSubviewName string 指定从子视图的名称，如果为空，则判定是否存在于任意一个关联的子视图中
---@return boolean 是否存在
function XEActorComponent:IsInSubview(pSubviewName) end


---@public 获取可能存在的Subview代理, 重载该函数以获取正确的subview代理
---@return XESubviewAgent
function XEActorComponent:GetSubviewAgent() end


---@public 获取所在的所有subview
---@return XESubview[]
---@return number
function XEActorComponent:GetAllSubviews() end


---@public 主体组件添加进subview后，依赖对象的同步处理
---@return boolean
function XEActorComponent:ResolveAddToSubviewDependency() end


---@public 主体组件从subview移除后，依赖对象的同步处理
---@return boolean
function XEActorComponent:ResolveRemoveFromSubviewDependency() end


---@public 从可能的顶点数据中获取合适的两边长作为subview纹理的两边长，一般为最长边的两点与其中位点此三点构成的两边。
---@param pViewport XEViewport 视口对象
---@return XVECTOR2
---@return boolean 是否成功
function XEActorComponent:GetSubviewEdgeLength(pViewport) end


---@public 获取引擎渲染图元
---@return IXPrimitiveBase
function XEActorComponent:GetRenderPrimitive() end


---@public 合并到世界矩阵
---@param mat XMATRIX4 offset
---@return boolean 是否成功
function XEActorComponent:MergeToWorldTransform(mat) end


---@public 设置当前非头饰的组件的世界矩阵
---@param mat XMATRIX4
---@return boolean 是否设置成功
function XEActorComponent:ApplyWorldTransform(mat) end


---@public 获取当前XEActor的原始世界矩阵，实际是从引擎获取当前实例的世界矩阵
---@return XMATRIX4
function XEActorComponent:GetRawWorldTransform() end


---@public 获取当前组件的父组件
---@return XEActorComponent
function XEActorComponent:GetAttachParentComponent() end


---@public 获取当前组件的所有子组件，包括直接子组件，也包括子组件所包含的子组件。即此函数用于获取当前组件的所有“子孙”组件.
---@return XEActorComponent[]
---@return void
function XEActorComponent:GetAllChildComponents() end


---@public 获取当前组件的所有直接子组件，不包括子组件所包含的子组件
---@return XEActorComponent[]
function XEActorComponent:GetChildComponents() end


---@public 判断当前组件是否有子组件
---@return boolean
function XEActorComponent:HasChildComponent() end


---@public 为当前组件添加子组件
---@param pChild XEActorComponent 将要添加到当前组件的子组件列表的组件
---@return void
function XEActorComponent:AddChildComponent(pChild) end


---@public 从当前组件移除指定的子组件
---@param pChild XEActorComponent 将要从当前组件的子组件列表中移除的组件
---@return void
function XEActorComponent:RemoveChildComponent(pChild) end


---@public 设置当前组件所属的XEActor
---@param pActor XEActor
---@return void
function XEActorComponent:SetActorOwner(pActor) end


---@public 获取当前组件所属的XEActor
---@return XEActor
function XEActorComponent:GetActorOwner() end


---@public 仅当前组件所属的XEActor置为空，但不释放其所指向的指针
---@return void
function XEActorComponent:ReleaseActorOwner() end


---@public 判断Transform是否处于合并模式
---@return boolean
function XEActorComponent:IsTransformMergeMode() end


---@public 获取当前组件的变换数据，包括世界坐标、朝向、大小等
---@return XETransform
function XEActorComponent:GetTransform() end


---@public 获取当前组件所处的世界对象，也就是当前组件所属的XEActor所处的世界
---@param bStandaloneOwnerWorldAsWell boolean
---@return XEWorld
function XEActorComponent:GetWorldOwner(bStandaloneOwnerWorldAsWell) end


---@public 获取当前组件所处的关卡对象，也就是当前组件所属的XEActor所处的关卡
---@param bStandaloneOwnerLevelAsWell boolean
---@return XELevel
function XEActorComponent:GetLevelOwner(bStandaloneOwnerLevelAsWell) end


---@public 设置当前组件所处的关卡对象，也就是当前组件所属的XEActor所处的关卡, 同时记录一下它所属的世界，关卡可能会先被释放
---@param pLevel XELevel
---@return void
function XEActorComponent:SetLevelOwner(pLevel) end


---@public 获取当前Actor在世界坐标系下的朝向(Z)单位向量
---@return XVECTOR3
function XEActorComponent:GetForwardVector() end


---@public 获取当前Actor在世界坐标系下的UP(Y)单位向量
---@return XVECTOR3
function XEActorComponent:GetUpVector() end


---@public 获取当前Actor在世界坐标系下的向右(X)单位向量
---@return XVECTOR3
function XEActorComponent:GetRightVector() end


---@public 在世界坐标系下，设置当前组件的朝向向量和UP向量。通过设置朝向向量和UP向量设置当前组件的旋转朝向
---@param vForwardDir XVECTOR3
---@param vUp XVECTOR3
---@return void
function XEActorComponent:SetForwardDirAndUp(vForwardDir, vUp) end


---@public 在世界坐标系下，设置当前组件的位置、朝向向量和UP向量，其中设置朝向向量和UP向量是为了计算当前组件的旋转状态
---@param vPosition XVECTOR3
---@param vForwardDir XVECTOR3
---@param vUp XVECTOR3
---@return void
function XEActorComponent:SetPositionAndForwardDirUp(vPosition, vForwardDir, vUp) end


---@public 将当前组件绕X轴旋转fDeltaRadian弧度。
---@param fDeltaRadian number
---@return void
function XEActorComponent:RotateX(fDeltaRadian) end


---@public 将当前组件绕Y轴旋转fDeltaRadian弧度。
---@param fDeltaRadian number
---@return void
function XEActorComponent:RotateY(fDeltaRadian) end


---@public 将当前组件绕Z轴旋转fDeltaRadian弧度。
---@param fDeltaRadian number
---@return void
function XEActorComponent:RotateZ(fDeltaRadian) end


---@public 将当前组件绕vRotateAxis轴旋转fDeltaRadian弧度
---@param vRotateAxis XVECTOR3
---@param fDeltaRadian number
---@return void
function XEActorComponent:RotateAxis(vRotateAxis, fDeltaRadian) end


---@public 应用局部坐标系下的些许位置变化
---@param deltaMovement XVECTOR3 位置变化大小
---@return void
function XEActorComponent:DeltaLocalMove(deltaMovement) end


---@public 应用局部坐标系下的些许旋转变化
---@param deltaRotateEuler XVECTOR3 旋转变化大小
---@return void
function XEActorComponent:DeltaLocalRotation(deltaRotateEuler) end


---@public 应用局部坐标系下的些许缩放变化
---@param deltaScale XVECTOR3 缩放变化大小
---@return void
function XEActorComponent:DeltaLocalScale(deltaScale) end


---@public 获取当前组件在局部坐标系的坐标，不是世界坐标系
---@return XVECTOR3
function XEActorComponent:GetLocation() end


---@public 获取当前组件在局部坐标系的四元数，四元数表示朝向
---@return XQUATERNION
function XEActorComponent:GetQuat() end


---@public 获取当前组件在局部坐标系的大小
---@return XVECTOR3
function XEActorComponent:GetScale() end


---@public 获取组件索引
---@return number
function XEActorComponent:GetIndex() end


---@public 判断当前组件是否被标记为已删除
---@return boolean
function XEActorComponent:IsDeleted() end


---@public 判断当前组件是否被修改
---@return boolean
function XEActorComponent:IsModified() end


---@public XEActorComponent_IsHidden00
---@return boolean
function XEActorComponent:IsHidden() end


---@public 标记当前组件是否被已修改
---@param bModified boolean
---@return void
function XEActorComponent:SetModified(bModified) end


---@public 获取当前组件在世界坐标系下的位置
---@return XVECTOR3
function XEActorComponent:GetWorldLocation() end


---@public 获取当前组件在世界坐标系下的旋转
---@return XQUATERNION
function XEActorComponent:GetWorldRotation() end


---@public 获取当前组件在世界坐标系下的缩放
---@return XVECTOR3
function XEActorComponent:GetWorldScale() end


---@public 获取当前组件在世界坐标系下的变换矩阵
---@return XMATRIX4
function XEActorComponent:GetWorldTransform() end


---@public 把一个模型坐标系下的位置坐标转换为世界坐标.
---@param position XVECTOR3
---@return XVECTOR3
function XEActorComponent:LocalToWorld(position) end


---@public 把一个模型坐标系下的位置或旋转坐标转换为世界坐标.
---@param vector XVECTOR4
---@return XVECTOR4
function XEActorComponent:LocalToWorld(vector) end


---@public 把一个世界坐标系下的位置坐标转换为局部坐标.
---@param position XVECTOR3
---@return XVECTOR3
function XEActorComponent:WorldToLocal(position) end


---@public 把一个世界坐标系下的位置或旋转坐标转换为局部坐标.
---@param vector XVECTOR4
---@return XVECTOR4
function XEActorComponent:WorldToLocal(vector) end


---@public 将当前组件的位置和朝向分别为设为vNewWorldLocation和qNewWorldQuaternion
---@param vNewWorldLocation XVECTOR3
---@param qNewWorldQuaternion XQUATERNION
---@return boolean
function XEActorComponent:SetWorldLocationAndRotation(vNewWorldLocation, qNewWorldQuaternion) end


---@public 将当前组件的位置和朝向分别为设为vNewWorldLocation和qNewWorldQuaternion
---@param vNewWorldLocation XVECTOR3
---@param qNewWorldQuaternion XQUATERNION
---@return boolean
function XEActorComponent:MoveComponent(vNewWorldLocation, qNewWorldQuaternion) end


---@public XEActorComponent_MoveComponent01
---@param vDelta XVECTOR3
---@param qNewRotation XQUATERNION
---@param bSweep boolean
---@param hit XEHitResult
---@param MoveFlags number
---@param Teleport number
---@return boolean
function XEActorComponent:MoveComponent(vDelta, qNewRotation, bSweep, hit, MoveFlags, Teleport) end


---@public 将当前组件的大小设vNewScale
---@param vNewScale XVECTOR3
---@return boolean
function XEActorComponent:ScaleComponent(vNewScale) end


---@public 更新当前组件的世界变换矩阵
---@return void
function XEActorComponent:UpdateWorldTransformCommon() end


---@public 获取当前组件到视口绑定的虚拟相机的距离
---@param pWorld  XEWorld
---@return number
function XEActorComponent:GetDistanceToCamera(pWorld) end


---@public XEActorComponent_FindFloor00
---@param hr XEHitResult
---@return boolean
function XEActorComponent:FindFloor(hr) end


---@type string @readonly 组件名
XEActorComponent.COMPONENT_TYPENAME = ''


---@type string @readonly 组件所在碰撞通道名称
XEActorComponent.RC_CHANNEL = ''


---@type number @readonly 组件dummy形状半径
XEActorComponent.DUMMY_SHAPE_RADIUS = 0


