---光源组件
---用于与引擎的 IXLightBase对象交互，用来设置光照强度、光照颜色、光源类型等
---@class XELightComponent : XEPrimitiveComponent
XELightComponent = {}


---@public XELightComponent_new00
---@return XELightComponent
function XELightComponent:new() end


---@public 创建引擎中封装的代表平行光的 IXLightBase 对象，并设置光源颜色、方向和强度
---@param color  XCOLORBASE 光源颜色
---@param vDir XVECTOR3 平行光的方向，单位化的向量
---@param fLuminance number 光照强度
---@return void
function XELightComponent:SetAsDirLight(color, vDir, fLuminance) end


---@public 创建引擎中封装的代表环境光的 IXLightBase 对象，并设置光源颜色、索引和强度
---@param color  XCOLORBASE 光源颜色
---@param index number 环境光的索引，目前引擎仅支持两个环境光
---@param fLuminance number 光照强度
---@return void
function XELightComponent:SetAsEnvLight(color, index, fLuminance) end


---@public 创建引擎中封装的代表点光源的 IXLightBase 对象，并设置光源参数
---@param desc  XPointLightDesc 点光源参数结构体
---@return void
function XELightComponent:SetAsPointLight(desc) end


---@public 创建引擎中封装的代表聚光源的 IXLightBase 对象，并设置光源参数
---@param desc  XSpotLightDesc 聚光源参数结构体
---@return void
function XELightComponent:SetAsSpotLight(desc) end


---@public 对于点光源或者聚光源，可以设置光源半径
---@param fRadius number 光源半径
---@return void
function XELightComponent:SetLightRadius(fRadius) end


---@public 对于点光源或者聚光源，可以设置光源衰减值
---@param fFallOffExponent number 光源衰减值
---@return void
function XELightComponent:SetLightFallOffExponent(fFallOffExponent) end


---@public 对于聚光源，可以设置光源内锥角
---@param fAngle number 角度
---@return void
function XELightComponent:SetLightConeInnerAngle(fAngle) end


---@public 对于聚光源，可以设置光源外锥角
---@param fAngle number 角度
---@return void
function XELightComponent:SetLightConeOuterAngle(fAngle) end


---@public 获取平行光（也叫方向光）的方向
---@return XVECTOR3
function XELightComponent:GetDirLightDir() end


---@public 获取光源颜色
---@return XCOLORBASE
function XELightComponent:GetLightColor() end


---@public 设置光源颜色
---@param color  XCOLORBASE
---@return boolean
function XELightComponent:SetLightColor(color) end


---@public 获取光照强度
---@return number
function XELightComponent:GetLightLuminance() end


---@public 设置光照强度
---@param fLuminance number
---@return boolean
function XELightComponent:SetLightLuminance(fLuminance) end


---@public 获取引擎封装的光源对象
---@return IXLightBase
function XELightComponent:GetLight() end


---@public 获取引擎封装的光源对象
---@return IXLightBase
function XELightComponent:GetLight() end


---@public 获取环境光索引
---@return number
function XELightComponent:GetLightIndex() end


---@public 光照是否准备好
---@return boolean
function XELightComponent:IsLightReady() end


---@type string @readonly Component类型名
XELightComponent.COMPONENT_TYPENAME = ''


