---@class XESubviewAgent
XESubviewAgent = {}


---@type number @enum eAgentType
XESubviewAgent.AT_UNKNOWN = 0


---@type number @enum eAgentType
XESubviewAgent.AT_COMPONENT = 0


---@public 授受代理的客户，客户为Actor组件
---@param pActorComponent XEActorComponent
---@return void
function XESubviewAgent:AcceptClient(pActorComponent) end


---@public 获取代理客户（未知类型）
---@return userdata
function XESubviewAgent:GetClient() end


---@public 获取Actor组件客户，返回为NULL时，客户不为Actor组件
---@return XEActorComponent
function XESubviewAgent:GetActorComponentClient() end


---@public 获取代理客户所在的世界
---@return XEWorld
function XESubviewAgent:GetClientWorld() end


---@public 获取引擎渲染图元
---@return IXPrimitiveBase
function XESubviewAgent:GetRenderPrimitive() end


---@public 设置subview的属性字节
---@param pSubviewName string
---@param attrBits number
---@param bSyncToSubviewHolder boolean 是否同步到实际的SubviewHolder中（如果是持有体的话）
---@return boolean
function XESubviewAgent:SetSubviewAttrBits(pSubviewName, attrBits, bSyncToSubviewHolder) end


---@public 获取subview的属性字节
---@param pSubviewName string
---@return number
function XESubviewAgent:GetSubviewAttrBits(pSubviewName) end


---@public 释放所有资源
---@return void
function XESubviewAgent:Release() end


---@public 获取该图元可能关联的subview处理图元
---@param pSubviewName string 指明subview的具体名称
---@param eRA number 指明要获取的Subviewprimitive的渲染属性，可为RA_AS_HOLDER，RA_AS_GUEST，RA_HOLDER_OR_GUEST_DONT_CARE其中之一
---@return SubviewPrimitive
function XESubviewAgent:GetSubviewPrimitive(pSubviewName, eRA) end


---@public 获取该图元可能关联的subview处理图元
---@param nSubviewIndex number 指明符合条件的subview序号
---@param eRA number 指明要获取的Subviewprimitive的渲染属性，可为RA_AS_HOLDER，RA_AS_GUEST，RA_HOLDER_OR_GUEST_DONT_CARE其中之一
---@return SubviewPrimitive
function XESubviewAgent:GetSubviewPrimitive(nSubviewIndex, eRA) end


---@public 添加到子视图中,子视图在世界中
---@param pWorld XEWorld 所在世界
---@param pSubviewName string 渲染的子视图名称
---@param bRenderOnlyInSubview boolean 是否只在子视图中渲染
---@param bResetupSubview boolean 是否立即重新安装子视图
---@return boolean 是否成功
function XESubviewAgent:AddToSubview(pWorld, pSubviewName, bRenderOnlyInSubview, bResetupSubview) end


---@public 从指定子视图中删除
---@param bResetupSubview boolean 是否立即重新安装子视图
---@param pSubviewName string 指定从子视图中移除的名称，如果为空，则该渲染图元将会从所有关联子视图中移除。
---@return boolean 是否成功
function XESubviewAgent:RemoveFromSubview(bResetupSubview, pSubviewName) end


---@public 从指定子视图中延时删除，该函数将不会立即更新子视图中实际图元，但是会删除中间关联数据体。在子视图的下一帧将更新一次实际渲染的子视图
---@param pSubviewName string 指定从子视图中移除的名称，如果为空，则该渲染图元将会从所有关联子视图中移除。
---@return boolean 是否成功
function XESubviewAgent:RemoveFromSubviewLater(pSubviewName) end


---@public 是否已经存在于一个子视图中
---@param pSubviewName string 指定从子视图的名称，如果为空，则判定是否存在于任意一个关联的子视图中
---@return boolean 是否存在
function XESubviewAgent:IsInSubview(pSubviewName) end


---@public 作为持有体绑定到子视图(内部参数快速设置）
---@param pWorld XEWorld 子视图所在世界
---@param pSubviewName string 渲染的子视图名称
---@param bCreatSubviewIfNotExist boolean 如果子视图不存在,则指定是否自动创建一个
---@param bCreateCameraForSubview boolean 是否为subview创建一个内部相机对象,并使用该相机,以当前视口中相机参数进行创建，如果要修改相机参数，请获取该视口相机并进行修改
---@return SubviewPrimitive 创建的SubvewPrimitive
function XESubviewAgent:BindSubview(pWorld, pSubviewName, bCreatSubviewIfNotExist, bCreateCameraForSubview) end


---@public 作为持有体绑定到子视图(完全使用传入参数）
---@param sp  SubviewPrimitive 包含所有绑定参数
---@param bCreatSubviewIfNotExist boolean 如果子视图不存在,则指定是否自动创建一个
---@return SubviewPrimitive 创建的SubvewPrimitive
function XESubviewAgent:BindSubview(sp, bCreatSubviewIfNotExist) end


---@public 从子视图中解除绑定
---@param bRemoveSubview boolean 是否在解除绑定后删除子视图
---@param pSubviewName string 指定子视图名称，如果为空，则解绑关联的所有子视图
---@return boolean 是否成功
function XESubviewAgent:UnBindSubview(bRemoveSubview, pSubviewName) end


---@public 获取Subview中相机
---@param pSubviewName string
---@return XBaseCamera
function XESubviewAgent:GetSubViewCamera(pSubviewName) end


