---@type number @enum eEventStatus
EVENT_STATUS_READY = 0


---@type number @enum eEventStatus
EVENT_STATUS_EXPLAIN = 0


---@type number @enum eEventStatus
EVENT_STATUS_ENTRANCE = 0


---@type number @enum eEventStatus
EVENT_STATUS_TRIGGER = 0


---@type number @enum eEventStatus
EVENT_STATUS_RESTORE = 0


---@type number @enum eEventStatus
EVENT_STATUS_CUSTOM = 0


---@type number @enum eEventStatus
EVENT_STATUS_RELEASE = 0


---事件的基类，封装了事件的一些基本操作
---@class XEEventBase : XOwnerRecorder
XEEventBase = {}


---@type number @enum eEventRemoveMode 自动删除
XEEventBase.ERM_AUTO = 0


---@type number @enum eEventRemoveMode 手动删除
XEEventBase.ERM_MANUAL = 0


---@type number @enum eEventExecuteMode 自动执行
XEEventBase.EEM_AUTO = 0


---@type number @enum eEventExecuteMode 手动执行
XEEventBase.EEM_MANUAL = 0


---@public XEEventBase_new00
---@return XEEventBase
function XEEventBase:new() end


---@public 更新事件
---@param fInterval number 间隔（ms）
---@return void
function XEEventBase:Tick(fInterval) end


---@public 释放事件资源
---@return void
function XEEventBase:Release() end


---@public 执行事件
---@param pWorld XEWorld
---@return void
function XEEventBase:Execute(pWorld) end


---@public 判断事件的广播接受者是否跟当前事件在同一个通道内
---@param szChannelName string
---@return boolean
---@attention 如果广播接收者和当前事件在同一个通道内，广播接收者响应事件执行的函数才会被调用
function XEEventBase:IsReceiverInChannel(szChannelName) end


---@public 获取事件列表
---@param pWorld XEWorld 世界指针，如果为空，返回全局事件列表；如果不为空，返回对应这个世界的事件列表
---@param pHasTheEvent boolean 返回列表中是否包含当前这个事件
---@return XEEventList
function XEEventBase:GetEventList(pWorld, pHasTheEvent) end


---@public 返回当前事件类型
---@return string
function XEEventBase:GetTypeName() end


---@public 设置事件数据
---@param val  XEVariant
---@return void
function XEEventBase:SetData(val) end


---@public 获取事件数据
---@return  XEVariant
function XEEventBase:GetData() end


---@public XEEventBase_GetData01
---@return XEVariant
function XEEventBase:GetData() end


---@public 设置事件发送者
---@param who userdata
---@return void
function XEEventBase:SetSender(who) end


---@public 获取事件发送者
---@return userdata
function XEEventBase:GetSender() end


---@public 设置事件是否可执行
---@param what userdata
---@return void
function XEEventBase:SetExcutable(what) end


---@public 判断事件是否可执行
---@return userdata
function XEEventBase:GetExcutable() end


---@public 设置事件名称
---@param szName string
---@return void
function XEEventBase:SetName(szName) end


---@public 获取事件名称
---@return string
function XEEventBase:GetName() end


---@public 添加事件监听者
---@param pListener XEEventBase::Listener
---@return void
function XEEventBase:AddListener(pListener) end


---@public 移除事件监听者
---@param pListener XEEventBase::Listener
---@return boolean
function XEEventBase:RemoveListener(pListener) end


---@public 设置被移除的状态（事件被移除状态为true，表明当前事件该被执行了）
---@return void
function XEEventBase:SetRemove() end


---@public 判断被移除的状态
---@return boolean
function XEEventBase:IsRemoved() end


---@public 设置事件被移除的方式（手动/自动）
---@param erm number
---@return void
function XEEventBase:SetRemoveMode(erm) end


---@public 获取事件被移除的方式（手动/自动）
---@return number
function XEEventBase:GetRemoveMode() end


---@public 设置事件被执行的方式（手动/自动）
---@param eem number
---@return void
function XEEventBase:SetExecuteMode(eem) end


---@public 获取事件被执行的方式（手动/自动）
---@return number
function XEEventBase:GetExecuteMode() end


---@public 恢复事件（设置事件被删除的状态为false）
---@return void
function XEEventBase:SetReserve() end


---@public 设置当前事件是否启用Tick
---@param bEnable boolean
---@return void
function XEEventBase:SetTickable(bEnable) end


---@public 判断当前事件是否启用Tick
---@return boolean
function XEEventBase:IsTickable() end


---@public 设置当前事件的倒计时时刻，如果事件设置了延时触发，则会启用倒计时，倒计时为0时，该事件被执行
---@param fMilliseconds number
---@return void
function XEEventBase:SetCountdownTime(fMilliseconds) end


---@public 获取当前事件的倒计时时刻
---@return number
function XEEventBase:GetCountdownTime() end


---@public 设置当前事件的状态
---@param erm number
---@return void
function XEEventBase:SetEventStatus(erm) end


---@public 获取当前事件的状态
---@return number
function XEEventBase:GetEventStatus() end


