---@class XELevel : XEActorContainer
XELevel = {}


---@public 为这个关卡加载场景内容, 关卡可用.xscene文件进行加载。如果在xscene文件中有同名的关卡，则加载这个关卡，否则将加载默认关卡
---in the format of "xx.xscene", if you don't want to use the relative as home path, set it to xfalse.
---@param pRelativePath string 场景文件的相对路径，此处的相对路径是指xscene文件相对于工程文件夹的路径。
---@param bUseDefaultLevelPathAsHome boolean 是否使用默认关卡里的场景路径作为根路径
---@return boolean 成功与否
function XELevel:Load(pRelativePath, bUseDefaultLevelPathAsHome) end


---@public 设置这个关卡为可在世界中表示的状态
---@param bSyncExclusingRenderObjectsToWorld boolean 是否将互斥渲染对象同步更新到World中，如Camera,lights等。
---@return void
function XELevel:Present(bSyncExclusingRenderObjectsToWorld) end


---@public 设置这个关卡为可在世界中不可表示的状态,
---@return void
function XELevel:UnPresent() end


---@public 只使该关卡在所属世界中生效
---@return void
function XELevel:PresentThisOnly() end


---@public 这个关卡为是否可在世界中表示的状态,
---@return boolean 是否可表示
function XELevel:IsPresent() end


---@public 初始化关卡
---@return void
function XELevel:Init() end


---@public 释放关卡
---@return void
function XELevel:Release() end


---@public 更新关卡Actor列表中未被标记为delete的Actor，更新物理世界、执行事件回调以及执行绑定脚本编辑器中的Tick响应函数等。
---@param fDelSecond number
---@return void
function XELevel:Tick(fDelSecond) end


---@public 渲染
---1 渲染当前世界的Actor列表中未被标记为删除和隐藏状态的Actor；
---2 如果当前世界的物理场景对象不为空，也会对物理场景执行渲染操作；
---3 执行绑定脚本编辑器中Render响应函数。
---@param pViewport XEViewport
---@return void
function XELevel:Render(pViewport) end


---@public 获取关卡一个有效的Actor名称
---@param strActorType string
---@return string
function XELevel:GetActorValidName(strActorType) end


---@public 获取关卡名称
---@return string
function XELevel:GetLevelName() end


---@public 判定该关卡是否为世界的默认关卡
---@return boolean
function XELevel:IsDefaultLevel() end


---@public XELevel_RayPickOne00
---@param HitResult XEHitResult
---@return boolean
function XELevel:RayPickOne(HitResult) end


---@public 设置当前Level的序号，用于排序使用
---@param nOrder number
---@return void
function XELevel:SetOrder(nOrder) end


---@public 获取当前Level的序号
---@return number
function XELevel:GetOrder() end


---@public 获取绑定脚本实例指针
---@return XEScriptContainerInstance
function XELevel:GetScriptContainerInstance() end


---@public 根据给定路径创建一个绑定脚本实例
---@param pAssetPath string
---@return boolean
function XELevel:AttachBindingScriptAsset(pAssetPath) end


---@public 移除绑定脚本实例
---@return void
function XELevel:DetachBindingScriptInstance() end


---@public 获取蓝图管理器
---@return XEPatchGraphManager
function XELevel:GetPatchGraphMgr() end


---@public 释放所有的蓝图实例
---@return void
function XELevel:ReleasePatchManager() end


---@type number @enum eRenderOption
XELevel.RO_UNKNOWN = 0


---@type number @enum eRenderOption
XELevel.RO_GATHERING = 0


---@type number @enum eRenderOption
XELevel.RO_UNIQUE = 0


---@public 设置图层的渲染选项
---@param ro number
---@return void
function XELevel:SetRenderOption(ro) end


---@public 获取图层的渲染选项
---@return number
function XELevel:GetRenderOption() end


